npstructures.Counter
====================

.. currentmodule:: npstructures

.. autoclass:: Counter

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Counter.__init__
      ~Counter.count
   
   

   
   
   